@@ -125,7 +125,6 @@ void Callback_ConnectButton(GtkWidget* button)  {
 		cmd = g_strdup_printf(".n%s\n.gS%d\n", config->nickname, gameid);
 	}
 
-	global->reconnected = FALSE;
 	client_connect(CONNECT_TYPE_MONOPD_GAME, host, port, cmd);
 }
 
@@ -457,9 +456,10 @@ void CallBack_response_changenick_window(GtkWidget* widget, gint response, GtkWi
 void CallBack_menu_reconnect(GtkWidget* widget)  {
 	(void)widget;
 	gchar buf[64];
-	gchar *filename, *host, *cmd;
+	gchar *filename, *host = NULL, *cmd;
 	guint32 port;
 	FILE *file;
+	size_t len;
 
 	if (global->phase > PHASE_GETGAMES) {
 		return;
@@ -478,21 +478,42 @@ void CallBack_menu_reconnect(GtkWidget* widget)  {
 		return;
 	}
 
-	fscanf(file, "%s\n", buf);
+	if (fgets(buf, sizeof(buf), file) == NULL) {
+		goto free_and_return;
+	}
+	len = strlen(buf);
+	if (buf[len-1] != '\n') {
+		goto free_and_return;
+	}
+	buf[len-1] = '\0';
 	host = g_strdup(buf);
 
-	fscanf(file, "%s\n", buf);
+	if (fgets(buf, sizeof(buf), file) == NULL) {
+		goto free_and_return;
+	}
+	len = strlen(buf);
+	if (buf[len-1] != '\n') {
+		goto free_and_return;
+	}
+	buf[len-1] = '\0';
 	port = atoi(buf);
 
-	fscanf(file, "%s\n", buf);
+	if (fgets(buf, sizeof(buf), file) == NULL) {
+		goto free_and_return;
+	}
+	len = strlen(buf);
+	if (buf[len-1] != '\n') {
+		goto free_and_return;
+	}
+	buf[len-1] = '\0';
 	cmd = g_strdup_printf(".R%s\n", buf);
 
-	fclose(file);
-
 	/* rejoin game */
-	global->reconnected = TRUE;
 	client_connect(CONNECT_TYPE_MONOPD_GAME, host, port, cmd);
-	g_free(host);
+
+free_and_return:
+	fclose(file);
+	if (host) g_free(host);
 }
 
 
