@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright © 2002-2014 Sylvain Rochet
+ *  Copyright © 2002-2015 Sylvain Rochet
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,10 +15,12 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  along with this program; see the file COPYING. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -35,29 +37,16 @@
 void display_init()  {
 
 	GtkWidget *vbox;
-	GtkWidget *alignment;
-	GtkWidget *label;
 	GtkWidget *text;
 	GtkTextBuffer *textbuff;
 	GtkTextIter textiter;
 	GtkWidget *scrolledwin;
-	GtkWidget *buttonsbox;
 
 	vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 15);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), 15);
 	g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter", vbox);
 	gtk_box_pack_start(GTK_BOX(currentgame->BoardCenter), vbox, TRUE, TRUE, 0);
 
-	/* create title */
-	alignment = gtk_alignment_new(0.5, 0.5, 1.0, 1.0);
-	gtk_box_pack_start(GTK_BOX(vbox), alignment, FALSE, FALSE, 0);
-
-	label = gtk_label_new(NULL);
-	g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title", label);
-	gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
-	gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-	gtk_container_add(GTK_CONTAINER(alignment), label);
-
 	/* create text view */
 	scrolledwin = gtk_scrolled_window_new(NULL,NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -72,14 +61,7 @@ void display_init()  {
 	g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_text", text);
 	gtk_container_add(GTK_CONTAINER(scrolledwin), text);
 
-	/* buttons box */
-	buttonsbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 15);
-	g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_buttons", buttonsbox);
-	gtk_box_pack_start(GTK_BOX(vbox), buttonsbox, FALSE, FALSE, 0);
-
 	gtk_widget_show_all(vbox);
-	gtk_widget_hide(label);
-	gtk_widget_hide(buttonsbox);
 }
 
 
@@ -107,37 +89,48 @@ void display_clear_text() {
 }
 
 
-void display_clear_buttons()  {
+void display_clear_buttons() {
 	GtkWidget *buttonsbox = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_buttons");
-	GList *list = gtk_container_get_children(GTK_CONTAINER(buttonsbox));
-	for (list = g_list_first(list); list; list = g_list_next(list)) {
-		gtk_widget_destroy(GTK_WIDGET(list->data));
+	if (buttonsbox) {
+		gtk_widget_destroy(buttonsbox);
+		g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_buttons", NULL);
 	}
-	g_list_free(list);
-	gtk_widget_hide(buttonsbox);
 }
 
 
 void display_estate(gint32 estateid)  {
-	GtkWidget *title = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title");
-
-	if (estateid < 0) {
-		gtk_widget_hide(title);
-		return;
-	}
-	display_title(currentgame->estate[estateid].name);
+	display_title(estateid < 0 ? NULL : currentgame->estate[estateid].name);
 }
 
 
 void display_title(gchar *title) {
-	GtkWidget *label;
-	gchar *tmp;
 
-	label = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title");
-	tmp = g_markup_printf_escaped("<span size=\"xx-large\"><b>%s</b></span>", title);
+	GtkWidget *label = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title");
+
+	if (!title) {
+		if (label) {
+			gtk_widget_destroy(label);
+			g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title", NULL);
+		}
+		return;
+	}
+
+	if (!label) {
+		GtkWidget *vbox = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter");
+		label = gtk_label_new(NULL);
+		gtk_label_set_use_markup(GTK_LABEL(label), TRUE);
+		gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
+		gtk_widget_set_halign(label, GTK_ALIGN_CENTER);
+		gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+		gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+		gtk_box_reorder_child(GTK_BOX(vbox), label, 0);
+		g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_title", label);
+		gtk_widget_show(label);
+	}
+
+	gchar *tmp = g_markup_printf_escaped("<span size=\"xx-large\"><b>%s</b></span>", title);
 	gtk_label_set_markup(GTK_LABEL(label), tmp);
 	g_free(tmp);
-	gtk_widget_show(label);
 }
 
 
@@ -146,6 +139,7 @@ void display_text(gchar *message) {
 	GtkWidget *text;
 	GtkTextBuffer *textbuff;
 	GtkTextIter textiter;
+	GtkTextMark *textmark;
 
 	text = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_text");
 	textbuff = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
@@ -154,6 +148,11 @@ void display_text(gchar *message) {
 		gtk_text_buffer_insert(textbuff, &textiter, "\n", 1);
 	}
 	gtk_text_buffer_insert(textbuff, &textiter, message, strlen(message));
+
+	/* Scroll to the end mark */
+	textmark = gtk_text_buffer_get_mark(textbuff, "endmark");
+	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(text), textmark,
+			0.0, FALSE, 0.0, 0.0);
 }
 
 
@@ -164,8 +163,14 @@ void display_add_button(gchar *caption, gchar *command, gboolean enabled) {
 	gchar *text;
 
 	buttonsbox = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_buttons");
+	if (!buttonsbox) {
+		GtkWidget *vbox = g_object_get_data(G_OBJECT(currentgame->BoardCenter), "boardcenter");
+		buttonsbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 15);
+		gtk_box_pack_start(GTK_BOX(vbox), buttonsbox, FALSE, FALSE, 0);
+		g_object_set_data(G_OBJECT(currentgame->BoardCenter), "boardcenter_buttons", buttonsbox);
+		gtk_widget_show(buttonsbox);
+	}
 
-	/* build button */
 	button = gtk_button_new_with_label(caption);
 	gtk_box_pack_start(GTK_BOX(buttonsbox), button, TRUE, TRUE, 0);
 
@@ -174,5 +179,5 @@ void display_add_button(gchar *caption, gchar *command, gboolean enabled) {
 	g_signal_connect(G_OBJECT(button), "clicked", G_CALLBACK(CallBack_button_command_pressed), NULL);
 	gtk_widget_set_sensitive(button, enabled);
 
-	gtk_widget_show_all(buttonsbox);
+	gtk_widget_show(button);
 }
