@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright © 2002-2014 Sylvain Rochet
+ *  Copyright © 2002-2015 Sylvain Rochet
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,28 +15,17 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  along with this program; see the file COPYING. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
+#ifndef ENGINE_H
+#define ENGINE_H
 
 /* all includes of engine */
 
-#ifndef _ENG_H
-#define _ENG_H
-
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
-
 #include "eng_main.h"
 #include "eng_frame.h"
 
-
-#ifdef __cplusplus
-}
-#endif
-#endif /* _ENG_H */
+#endif /* ENGINE_H */
 
