@@ -30,13 +30,21 @@
 #include "engine.h"
 
 #ifndef WIN32
+
 typedef int socket_t;
-#else
+#define ICON_PATH_SUFFIX "/apps/gtkatlantic.png"
+
+#else /* WIN32 */
+
 #include <winsock2.h>
 typedef SOCKET socket_t;
 #undef PACKAGE_DATA_DIR
+#undef PACKAGE_ICON_DIR
 #define PACKAGE_DATA_DIR "./data"
-#endif
+#define PACKAGE_ICON_DIR "./data/icons"
+#define ICON_PATH_SUFFIX ".png"
+
+#endif /* WIN32 */
 
 /* -- hierarchy
  *
@@ -527,7 +535,6 @@ typedef struct  {
 	GtkWidget *HelpWin;
 	GtkWidget *ThemeWin;
 
-	gboolean reconnected; /* whether we are reconnecting */
 	gint32 my_playerid;
 	gchar   *cookie;
 } _global;
