@@ -52,15 +52,15 @@ void interface_create_mainwindow()  {
 
 	/* icons */
 	GList *iconlist = NULL;
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_DATA_DIR "/icon_128x128.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/128x128" ICON_PATH_SUFFIX, NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_DATA_DIR "/icon_64x64.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/64x64" ICON_PATH_SUFFIX, NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_DATA_DIR "/icon_48x48.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/48x48" ICON_PATH_SUFFIX, NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_DATA_DIR "/icon_32x32.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/32x32" ICON_PATH_SUFFIX, NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
-	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_DATA_DIR "/icon_16x16.png", NULL);
+	pixbuf = gdk_pixbuf_new_from_file (PACKAGE_ICON_DIR "/16x16" ICON_PATH_SUFFIX, NULL);
 	if (pixbuf) iconlist = g_list_append(iconlist, pixbuf);
 	gtk_window_set_default_icon_list(iconlist);
 
