@@ -40,16 +40,14 @@
 /* parse a config file */
 gint8 parse_file_config(gchar *filename)  {
 
-	gchar *str, *ident, *tmp;
+	gchar str[512], *ident, *tmp;
 	FILE *file;
+	char *ret;
 
-	/* parse general group */
 	file = fopen(filename, "r");
 	if (!file) return -1;
 
-	str = g_malloc0(512);
-
-	for( fgets(str, 512, file) ; !feof(file) ; fgets(str, 512, file) )  {
+	for (ret = fgets(str, 512, file); ret && !feof(file); ret = fgets(str, 512, file)) {
 
 		ident = parser_get_identifier(str);
 		if(!ident) continue;
@@ -124,8 +122,6 @@ gint8 parse_file_config(gchar *filename)  {
 	}
 
 	fclose(file);
-	g_free(str);
-
 	return 0;
 }
 
