@@ -51,7 +51,11 @@ gint8 readpng_read(gchar *path, _png_imagedata *png_imagedata) {
 	}
 
 	memset(sig, 0, sizeof(sig));
-	fread(sig, 1, sizeof(sig), infile);
+	if (fread(sig, 1, sizeof(sig), infile) != sizeof(sig)) {
+		fprintf(stderr, "failed to read file: %s\n", path);
+		ret = -1;
+		goto free_and_return;
+	}
 	if (png_sig_cmp((png_bytep)sig, 0, sizeof(sig))) {
 		fprintf(stderr, "not a valid PNG file: %s\n", path);
 		ret = -1;
