@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright © 2002-2014 Sylvain Rochet
+ *  Copyright © 2002-2015 Sylvain Rochet
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,10 +15,13 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  along with this program; see the file COPYING. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
+#ifndef READPNG_H
+#define READPNG_H
+
 #include <glib.h>
 #include <png.h>
 
@@ -36,3 +39,5 @@ gint32 readpng_get_height(_png_imagedata *png_imagedata);
 guint8 *readpng_get_rgba(_png_imagedata *png_imagedata);
 guint8 *readpng_get_rgba_crop(_png_imagedata *png_imagedata, gint32 x, gint32 y, gint32 width, gint32 height);
 void readpng_cleanup(_png_imagedata *png_imagedata);
+
+#endif /* READPNG_H */
