@@ -135,9 +135,10 @@ void theme_del_entry(guint32 slot) {
 void theme_add_entry(gchar *path)  {
 
 	guint32 slot, area = 0;
-	gchar *path2, *str, *ident;
+	gchar *path2, str[512], *ident;
 	struct stat s;
 	FILE *file;
+	char *ret;
 
 	gchar *name = 0, *type = 0, *version = 0, *author = 0, *email = 0, *preview = 0;
 
@@ -155,10 +156,7 @@ void theme_add_entry(gchar *path)  {
 	file = fopen(path2, "r");
 	if (!file) return;
 
-	str = g_malloc0(512);
-
-	for( fgets(str, 512, file) ; !feof(file) ; fgets(str, 512, file) )
-	{
+	for (ret = fgets(str, 512, file); ret && !feof(file); ret = fgets(str, 512, file)) {
 
 		if (str[0] == '[')  {
 
@@ -192,8 +190,6 @@ void theme_add_entry(gchar *path)  {
 	}
 	fclose(file);
 
-	g_free(str);
-
 
 	/* giving up if theme provide no name or no type */
 	if(!name  ||  !type)  return;
