@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright © 2002-2014 Sylvain Rochet
+ *  Copyright © 2002-2015 Sylvain Rochet
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,10 +15,13 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  along with this program; see the file COPYING. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
+#ifndef THEME_H
+#define THEME_H
+
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
 
@@ -42,3 +45,5 @@ void     theme_display(gint32 themeid);
 guint8*  theme_preview_read(gint32 themeid, guint32 *width, guint32 *height);
 void     theme_load(gint32 themeid);
 void     on_theme_preview_draw(GtkWidget *widget, cairo_t *cr, gpointer data);
+
+#endif /* THEME_H */
