@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright © 2002-2014 Sylvain Rochet
+ *  Copyright © 2002-2015 Sylvain Rochet
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,10 +15,12 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  along with this program; see the file COPYING. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -46,7 +48,7 @@ void trade_initnew(gint32 tradeid)  {
 
 		/* no trade slot valid -> reject trade */
 		sendstr = g_strdup_printf(".Tr%d\n", tradeid);
-		client_send(global->game_connectid, sendstr, strlen(sendstr));
+		client_send(global->game_connect, sendstr);
 		g_free(sendstr);
 		return;
 	}
@@ -100,7 +102,6 @@ void trade_create_panel(gint32 tradeslot)  {
 	TradeWin = currentgame->trade[tradeslot].TradeWin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_size_request(TradeWin, 600, 220);
 	gtk_window_set_title(GTK_WINDOW(TradeWin), "GtkAtlantic: Trade");
-	gtk_window_set_icon(GTK_WINDOW(global->MainWin), global->icon_pixbuf);
 	g_object_set_data(G_OBJECT(TradeWin), "command", GINT_TO_POINTER(TRADE_ACTION_REJECT));
 	g_object_set_data(G_OBJECT(TradeWin), "tradeid", GINT_TO_POINTER(currentgame->trade[tradeslot].tradeid));
 	g_signal_connect(G_OBJECT(TradeWin), "delete_event", G_CALLBACK(CallBack_trade_button), NULL);
@@ -224,18 +225,15 @@ void trade_rebuild_playerlist(gint32 tradeslot)  {
 	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(PlayerList)));
 	gtk_list_store_clear(store);
 
-	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
+	for (i = 0; i < TRADE_MAX_PLAYER; i++)  {
+		trade_player *p = &currentgame->trade[tradeslot].player[i];
 		GtkTreeIter iter;
-
-		if(! global->player[i].playerid) continue;
-		if (global->player[i].spectator) continue;
-		if(global->player[i].game != currentgame->gameid)  continue;
-		if(! currentgame->trade[tradeslot].player[i][TRADE_PLAYER_PARTICIPATE]) continue;
+		if (!p->player) continue;
 
 		gtk_list_store_append(store, &iter);
 		gtk_list_store_set(store, &iter,
-		  TRADEPLAYERLIST_COLUMN_NAME, global->player[i].name,
-		  TRADEPLAYERLIST_BGCOLOR_NAME, currentgame->trade[tradeslot].player[i][TRADE_PLAYER_ACCEPT] ? "green" : "red",
+		  TRADEPLAYERLIST_COLUMN_NAME, p->player->name,
+		  TRADEPLAYERLIST_BGCOLOR_NAME, p->accept ? "#c8ffc8" : "#ffc8c8",
 		  -1);
 	}
 }
@@ -293,10 +291,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 		GtkWidget *Label;
 		GtkWidget *Entry;
 		GtkWidget *Combo;
-		GtkWidget *Alignment;
-			GtkWidget *Button;
+		GtkWidget *Button;
 
 	guint32 i;
+	player *p;
 
 	if(!currentgame->trade[tradeslot].ComponentBox) return;
 
@@ -313,14 +311,12 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 		case TRADE_TYPE_ESTATE:
 
 			/* update button */
-			Alignment = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-			gtk_box_pack_end(GTK_BOX(box), Alignment, FALSE, FALSE, 0);
-
 			Button = gtk_button_new_with_label("Update");
 			g_object_set_data(G_OBJECT(Button), "tradeid", GINT_TO_POINTER(currentgame->trade[tradeslot].tradeid));
-
 			g_signal_connect(G_OBJECT(Button), "clicked", G_CALLBACK(CallBack_trade_update_component), NULL);
-			gtk_container_add(GTK_CONTAINER(Alignment), Button);
+			gtk_widget_set_halign(Button, GTK_ALIGN_CENTER);
+			gtk_widget_set_valign(Button, GTK_ALIGN_CENTER);
+			gtk_box_pack_end(GTK_BOX(box), Button, FALSE, FALSE, 0);
 
 			/* valid estates */
 			Combo = gtk_combo_box_text_new();
@@ -345,12 +341,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			g_object_set_data(G_OBJECT(Button), "name_target_player", Combo);
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
 
-			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
-
-				if(!global->player[i].playerid)  continue;
-				if (global->player[i].spectator) continue;
-				if(global->player[i].game != currentgame->gameid)  continue;
-				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), global->player[i].name);
+			for (p = player_h; p; p = p->next) {
+				if (p->spectator) continue;
+				if (p->game != currentgame->gameid) continue;
+				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), p->name);
 			}
 
 			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
@@ -361,13 +355,12 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 		case TRADE_TYPE_MONEY:
 
 			/* update button */
-			Alignment = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-			gtk_box_pack_end(GTK_BOX(box), Alignment, FALSE, FALSE, 0);
-
 			Button = gtk_button_new_with_label("Update");
 			g_object_set_data(G_OBJECT(Button), "tradeid", GINT_TO_POINTER(currentgame->trade[tradeslot].tradeid));
 			g_signal_connect(G_OBJECT(Button), "clicked", G_CALLBACK(CallBack_trade_update_component), NULL);
-			gtk_container_add(GTK_CONTAINER(Alignment), Button);
+			gtk_widget_set_halign(Button, GTK_ALIGN_CENTER);
+			gtk_widget_set_valign(Button, GTK_ALIGN_CENTER);
+			gtk_box_pack_end(GTK_BOX(box), Button, FALSE, FALSE, 0);
 
 			/* amount of money */
 			Entry = gtk_entry_new();
@@ -384,12 +377,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			g_object_set_data(G_OBJECT(Button), "name_from_player", Combo);
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
 
-			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
-
-				if(!global->player[i].playerid)  continue;
-				if (global->player[i].spectator) continue;
-				if(global->player[i].game != currentgame->gameid)  continue;
-				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), global->player[i].name);
+			for (p = player_h; p; p = p->next)  {
+				if (p->spectator) continue;
+				if (p->game != currentgame->gameid) continue;
+				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), p->name);
 
 			}
 
@@ -404,12 +395,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			g_object_set_data(G_OBJECT(Button), "name_to_player", Combo);
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
 
-			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
-
-				if(!global->player[i].playerid)  continue;
-				if (global->player[i].spectator) continue;
-				if(global->player[i].game != currentgame->gameid)  continue;
-				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), global->player[i].name);
+			for (p = player_h; p; p = p->next) {
+				if (p->spectator) continue;
+				if (p->game != currentgame->gameid) continue;
+				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), p->name);
 			}
 			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
@@ -419,13 +408,12 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 		case TRADE_TYPE_CARD:
 
 			/* update button */
-			Alignment = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
-			gtk_box_pack_end(GTK_BOX(box), Alignment, FALSE, FALSE, 0);
-
 			Button = gtk_button_new_with_label("Update");
 			g_object_set_data(G_OBJECT(Button), "tradeid", GINT_TO_POINTER(currentgame->trade[tradeslot].tradeid));
 			g_signal_connect(G_OBJECT(Button), "clicked", G_CALLBACK(CallBack_trade_update_component), NULL);
-			gtk_container_add(GTK_CONTAINER(Alignment), Button);
+			gtk_widget_set_halign(Button, GTK_ALIGN_CENTER);
+			gtk_widget_set_valign(Button, GTK_ALIGN_CENTER);
+			gtk_box_pack_end(GTK_BOX(box), Button, FALSE, FALSE, 0);
 
 			/* valid cards */
 			Combo = gtk_combo_box_text_new();
@@ -436,7 +424,7 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 				gchar *tmp;
 
 				if(!currentgame->card[i].owner)  continue;
-				tmp = g_strdup_printf("%d", currentgame->card[i].cardid);
+				tmp = g_strdup_printf("%d: %s", currentgame->card[i].cardid, currentgame->card[i].title);
 				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), tmp);
 				g_free(tmp);
 			}
@@ -451,12 +439,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			g_object_set_data(G_OBJECT(Button), "name_target_player", Combo);
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
 
-			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
-
-				if(!global->player[i].playerid)  continue;
-				if (global->player[i].spectator) continue;
-				if(global->player[i].game != currentgame->gameid)  continue;
-				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), global->player[i].name);
+			for (p = player_h; p; p = p->next) {
+				if (p->spectator) continue;
+				if (p->game != currentgame->gameid) continue;
+				gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(Combo), p->name);
 			}
 			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
@@ -471,7 +457,7 @@ void trade_update_revision(gint32 tradeid, gint32 revision) {
 	gint32 tradeslot;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
-	if(tradeslot < 0) return;
+	if (tradeslot < 0) return;
 
 	currentgame->trade[tradeslot].revision = revision;
 }
@@ -479,16 +465,30 @@ void trade_update_revision(gint32 tradeid, gint32 revision) {
 
 void trade_update_player(gint32 tradeid, gint32 playerid, gboolean accept)  {
 
-	gint32 tradeslot, playerslot;
+	gint32 tradeslot;
+	gint32 i;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
-	playerslot = get_player_slot_with_playerid(playerid);
-	if(tradeslot < 0) return;
-	if(playerslot < 0) return;
+	if (tradeslot < 0) return;
 
-	currentgame->trade[tradeslot].player[playerslot][TRADE_PLAYER_PARTICIPATE] = TRUE;
-	currentgame->trade[tradeslot].player[playerslot][TRADE_PLAYER_ACCEPT] = accept;
-	trade_rebuild_playerlist(tradeslot);
+	for (i = 0; i < TRADE_MAX_PLAYER; i++) {
+		trade_player *p = &currentgame->trade[tradeslot].player[i];
+		if (!p->player) continue;
+		if ((gint32)p->player->playerid != playerid) continue;
+		p->accept = accept;
+		trade_rebuild_playerlist(tradeslot);
+		return;
+	}
+
+	/* new participating player */
+	for (i = 0; i < TRADE_MAX_PLAYER; i++) {
+		trade_player *p = &currentgame->trade[tradeslot].player[i];
+		if (p->player) continue;
+		p->player = player_from_id(playerid);
+		p->accept = accept;
+		trade_rebuild_playerlist(tradeslot);
+		return;
+	}
 }
 
 
@@ -502,9 +502,11 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 	gboolean valid;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
+	if (tradeslot < 0) return;
+
 	ProposalList = currentgame->trade[tradeslot].ProposalList;
-	from = global->player[ get_player_slot_with_playerid( currentgame->card[ get_card_slot_with_cardid(cardid)  ].owner ) ].name;
-	to = global->player[ get_player_slot_with_playerid(targetplayer) ].name;
+	from = player_from_id(currentgame->card[get_card_slot_with_cardid(cardid)].owner)->name;
+	to = player_from_id(targetplayer)->name;
 	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(ProposalList)));
 
 	/* remove previous cardid */
@@ -528,7 +530,7 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 		return;
 	}
 
-	cardname = g_strdup_printf("card #%d", cardid);
+	cardname = g_strdup_printf("card %d: %s", cardid, currentgame->card[ get_card_slot_with_cardid(cardid)  ].title);
 
 	gtk_list_store_append(store, &iter);
 	gtk_list_store_set(store, &iter,
@@ -557,9 +559,11 @@ void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)
 	gboolean valid;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
+	if (tradeslot < 0) return;
+
 	ProposalList = currentgame->trade[tradeslot].ProposalList;
-	from = global->player[ get_player_slot_with_playerid(currentgame->estate[estateid].owner) ].name;
-	to = global->player[ get_player_slot_with_playerid(targetplayer) ].name;
+	from = player_from_id(currentgame->estate[estateid].owner)->name;
+	to = player_from_id(targetplayer)->name;
 	estatename = currentgame->estate[estateid].name;
 	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(ProposalList)));
 
@@ -609,9 +613,11 @@ void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint
 	gboolean valid;
 
 	tradeslot = get_trade_slot_with_tradeid(tradeid);
+	if (tradeslot < 0) return;
+
 	ProposalList = currentgame->trade[tradeslot].ProposalList;
-	from = global->player[ get_player_slot_with_playerid(playerfrom) ].name;
-	to = global->player[ get_player_slot_with_playerid(playerto) ].name;
+	from = player_from_id(playerfrom)->name;
+	to = player_from_id(playerto)->name;
 	store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(ProposalList)));
 
 	/* remove all money proposal if same playerfrom and same playerto */
